#### What I'm trying to do and why

#### Steps to reproduce (if a bug)

Include (sanitized) borgmatic configuration files if applicable.

#### Actual behavior (if a bug)

Include (sanitized) `--verbosity 2` output if applicable.

#### Expected behavior (if a bug)

#### Other notes / implementation ideas

#### Environment

**borgmatic version:** [version here]

Use `sudo borgmatic --version` or `sudo pip show borgmatic | grep ^Version`

**borgmatic installation method:** [e.g., Debian package, Docker container, etc.]

**Borg version:** [version here]

Use `sudo borg --version`

**Python version:** [version here]

Use `python3 --version`

**Database version (if applicable):** [version here]

Use `psql --version` or `mysql --version` on client and server.

**operating system and version:** [OS here]
